@@ -1,4 +1,4 @@
-from objects import Enemy
+from bluebeam.objects import Enemy
 import pygame
 import math
 import os
